/*
 * Copyright 2016 - 2025 Gary Talent (gary@drinkingtea.net). All rights reserved.
 */

#include <studio/imguiutil.hpp>

#include "deleteconfirmation.hpp"

namespace studio {

DeleteConfirmation::DeleteConfirmation() noexcept {
	setTitle("Delete Item");
}

void DeleteConfirmation::openPath(ox::StringViewCR path) noexcept {
	open();
	m_path = path;
}

void DeleteConfirmation::open() noexcept {
	m_path = "";
	m_stage = Stage::Opening;
}

void DeleteConfirmation::close() noexcept {
	m_stage = Stage::Closed;
	m_open = false;
}

bool DeleteConfirmation::isOpen() const noexcept {
	return m_open;
}

void DeleteConfirmation::draw(StudioContext &ctx) noexcept {
	switch (m_stage) {
		case Stage::Closed:
			break;
		case Stage::Opening:
			ImGui::OpenPopup(title().c_str());
			m_stage = Stage::Open;
			m_open = true;
		[[fallthrough]];
		case Stage::Open:
			drawWindow(ctx.tctx, m_open, [this] {
				ImGui::Text("Are you sure you want to delete %s?", m_path.c_str());
				if (ig::PopupControlsOkCancel(m_open, "Yes", "No") != ig::PopupResponse::None) {
					deleteFile.emit(m_path);
					close();
				}
			});
			break;
	}
}

}
